==> gura-0.6.2-src.tar.gz: gura-0.6.2/src/module-wx/Class_wx_DateEvent.h <==
//----------------------------------------------------------------------------
// wxDateEvent
// extracted from dateevt.tex
//----------------------------------------------------------------------------
#ifndef __CLASS_WX_DATEEVENT_H__
#define __CLASS_WX_DATEEVENT_H__

Gura_BeginModuleScope(wx)

//----------------------------------------------------------------------------
// Class declaration for wxDateEvent
//----------------------------------------------------------------------------
Gura_DeclareUserClass(wx_DateEvent);

//----------------------------------------------------------------------------
// Object declaration for wxDateEvent
//----------------------------------------------------------------------------
class Object_wx_DateEvent : public Object_wx_CommandEvent {
public:
	Gura_DeclareObjectAccessor(wx_DateEvent)
public:
	inline Object_wx_DateEvent(wxDateEvent *pEntity, GuraObjectObserver *pObserver, bool ownerFlag) :
				Object_wx_CommandEvent(Gura_UserClass(wx_DateEvent), pEntity, pObserver, ownerFlag) {}
	inline Object_wx_DateEvent(Class *pClass, wxDateEvent *pEntity, GuraObjectObserver *pObserver, bool ownerFlag) :
				Object_wx_CommandEvent(pClass, pEntity, pObserver, ownerFlag) {}
	virtual ~Object_wx_DateEvent();
	virtual Object *Clone() const;
	virtual String ToString(bool exprFlag);
	inline wxDateEvent *GetEntity() {
		return dynamic_cast<wxDateEvent *>(_pEntity);
	}
	inline wxDateEvent *ReleaseEntity() {
		wxDateEvent *pEntity = GetEntity();
		InvalidateEntity();
		return pEntity;
	}
	inline bool IsInvalid(Signal sig) const {
		if (_pEntity != NULL) return false;
		SetError_InvalidWxObject(sig, "wxDateEvent");
		return true;
	}
};

Gura_EndModuleScope(wx)

#endif

==> gura-0.7.0-src.tar.gz: gura-0.7.0/src/module-wx/Class_wx_DateEvent.h <==
//----------------------------------------------------------------------------
// wxDateEvent
// extracted from dateevt.tex
//----------------------------------------------------------------------------
#ifndef __CLASS_WX_DATEEVENT_H__
#define __CLASS_WX_DATEEVENT_H__

Gura_BeginModuleScope(wx)

//----------------------------------------------------------------------------
// Class declaration for wxDateEvent
//----------------------------------------------------------------------------
Gura_DeclareUserClass(wx_DateEvent);

//----------------------------------------------------------------------------
// Object declaration for wxDateEvent
//----------------------------------------------------------------------------
class Object_wx_DateEvent : public Object_wx_CommandEvent {
public:
	Gura_DeclareObjectAccessor(wx_DateEvent)
public:
	inline Object_wx_DateEvent(wxDateEvent *pEntity, GuraObjectObserver *pObserver, bool ownerFlag) :
				Object_wx_CommandEvent(Gura_UserClass(wx_DateEvent), pEntity, pObserver, ownerFlag) {}
	inline Object_wx_DateEvent(Class *pClass, wxDateEvent *pEntity, GuraObjectObserver *pObserver, bool ownerFlag) :
				Object_wx_CommandEvent(pClass, pEntity, pObserver, ownerFlag) {}
	virtual ~Object_wx_DateEvent();
	virtual Object *Clone() const;
	virtual String ToString(bool exprFlag);
	inline wxDateEvent *GetEntity() {
		return dynamic_cast<wxDateEvent *>(_pEntity);
	}
	inline wxDateEvent *ReleaseEntity() {
		wxDateEvent *pEntity = GetEntity();
		InvalidateEntity();
		return pEntity;
	}
	inline bool IsInvalid(Signal &sig) const {
		if (_pEntity != nullptr) return false;
		SetError_InvalidWxObject(sig, "wxDateEvent");
		return true;
	}
};

Gura_EndModuleScope(wx)

#endif
